==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DeviceAssuranceAndroidPlatform.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DeviceAssurance;
import com.okta.sdk.resource.model.DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType;
import com.okta.sdk.resource.model.DeviceAssuranceAndroidPlatformAllOfScreenLockType;
import com.okta.sdk.resource.model.LinksSelf;
import com.okta.sdk.resource.model.OSVersion;
import com.okta.sdk.resource.model.Platform;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DeviceAssuranceAndroidPlatform
 */
@JsonPropertyOrder({ DeviceAssuranceAndroidPlatform.JSON_PROPERTY_DISK_ENCRYPTION_TYPE,
        DeviceAssuranceAndroidPlatform.JSON_PROPERTY_JAILBREAK, DeviceAssuranceAndroidPlatform.JSON_PROPERTY_OS_VERSION,
        DeviceAssuranceAndroidPlatform.JSON_PROPERTY_SCREEN_LOCK_TYPE,
        DeviceAssuranceAndroidPlatform.JSON_PROPERTY_SECURE_HARDWARE_PRESENT })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "platform", visible = true, defaultImpl = DeviceAssuranceAndroidPlatform.class)

public class DeviceAssuranceAndroidPlatform extends DeviceAssurance implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DISK_ENCRYPTION_TYPE = "diskEncryptionType";
    private DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType diskEncryptionType;

    public static final String JSON_PROPERTY_JAILBREAK = "jailbreak";
    private Boolean jailbreak;

    public static final String JSON_PROPERTY_OS_VERSION = "osVersion";
    private OSVersion osVersion;

    public static final String JSON_PROPERTY_SCREEN_LOCK_TYPE = "screenLockType";
    private DeviceAssuranceAndroidPlatformAllOfScreenLockType screenLockType;

    public static final String JSON_PROPERTY_SECURE_HARDWARE_PRESENT = "secureHardwarePresent";
    private Boolean secureHardwarePresent;

    public DeviceAssuranceAndroidPlatform() {
    }

    /*
     * @JsonCreator public DeviceAssuranceAndroidPlatform(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_BY) String createdBy,
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_DATE) String createdDate,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATE) String lastUpdate,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED_BY) String lastUpdatedBy ) { this(); this.createdBy = createdBy;
     * this.createdDate = createdDate; this.id = id; this.lastUpdate = lastUpdate; this.lastUpdatedBy = lastUpdatedBy; }
     */

    public DeviceAssuranceAndroidPlatform diskEncryptionType(
            DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType diskEncryptionType) {

        this.diskEncryptionType = diskEncryptionType;
        return this;
    }

    /**
     * Get diskEncryptionType
     *
     * @return diskEncryptionType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DISK_ENCRYPTION_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType getDiskEncryptionType() {
        return diskEncryptionType;
    }

    @JsonProperty(JSON_PROPERTY_DISK_ENCRYPTION_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDiskEncryptionType(DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType diskEncryptionType) {
        this.diskEncryptionType = diskEncryptionType;
    }

    public DeviceAssuranceAndroidPlatform jailbreak(Boolean jailbreak) {

        this.jailbreak = jailbreak;
        return this;
    }

    /**
     * Get jailbreak
     *
     * @return jailbreak
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_JAILBREAK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getJailbreak() {
        return jailbreak;
    }

    @JsonProperty(JSON_PROPERTY_JAILBREAK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setJailbreak(Boolean jailbreak) {
        this.jailbreak = jailbreak;
    }

    public DeviceAssuranceAndroidPlatform osVersion(OSVersion osVersion) {

        this.osVersion = osVersion;
        return this;
    }

    /**
     * Get osVersion
     *
     * @return osVersion
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OS_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OSVersion getOsVersion() {
        return osVersion;
    }

    @JsonProperty(JSON_PROPERTY_OS_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOsVersion(OSVersion osVersion) {
        this.osVersion = osVersion;
    }

    public DeviceAssuranceAndroidPlatform screenLockType(
            DeviceAssuranceAndroidPlatformAllOfScreenLockType screenLockType) {

        this.screenLockType = screenLockType;
        return this;
    }

    /**
     * Get screenLockType
     *
     * @return screenLockType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SCREEN_LOCK_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DeviceAssuranceAndroidPlatformAllOfScreenLockType getScreenLockType() {
        return screenLockType;
    }

    @JsonProperty(JSON_PROPERTY_SCREEN_LOCK_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setScreenLockType(DeviceAssuranceAndroidPlatformAllOfScreenLockType screenLockType) {
        this.screenLockType = screenLockType;
    }

    public DeviceAssuranceAndroidPlatform secureHardwarePresent(Boolean secureHardwarePresent) {

        this.secureHardwarePresent = secureHardwarePresent;
        return this;
    }

    /**
     * Get secureHardwarePresent
     *
     * @return secureHardwarePresent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SECURE_HARDWARE_PRESENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getSecureHardwarePresent() {
        return secureHardwarePresent;
    }

    @JsonProperty(JSON_PROPERTY_SECURE_HARDWARE_PRESENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSecureHardwarePresent(Boolean secureHardwarePresent) {
        this.secureHardwarePresent = secureHardwarePresent;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceAndroidPlatform deviceAssuranceAndroidPlatform = (DeviceAssuranceAndroidPlatform) o;
        return Objects.equals(this.diskEncryptionType, deviceAssuranceAndroidPlatform.diskEncryptionType)
                && Objects.equals(this.jailbreak, deviceAssuranceAndroidPlatform.jailbreak)
                && Objects.equals(this.osVersion, deviceAssuranceAndroidPlatform.osVersion)
                && Objects.equals(this.screenLockType, deviceAssuranceAndroidPlatform.screenLockType)
                && Objects.equals(this.secureHardwarePresent, deviceAssuranceAndroidPlatform.secureHardwarePresent);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(diskEncryptionType, jailbreak, osVersion, screenLockType, secureHardwarePresent,
                super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceAndroidPlatform {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    diskEncryptionType: ").append(toIndentedString(diskEncryptionType)).append("\n");
        sb.append("    jailbreak: ").append(toIndentedString(jailbreak)).append("\n");
        sb.append("    osVersion: ").append(toIndentedString(osVersion)).append("\n");
        sb.append("    screenLockType: ").append(toIndentedString(screenLockType)).append("\n");
        sb.append("    secureHardwarePresent: ").append(toIndentedString(secureHardwarePresent)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DeviceAssuranceAndroidPlatform.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DeviceAssurance;
import com.okta.sdk.resource.model.DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType;
import com.okta.sdk.resource.model.DeviceAssuranceAndroidPlatformAllOfScreenLockType;
import com.okta.sdk.resource.model.LinksSelf;
import com.okta.sdk.resource.model.OSVersion;
import com.okta.sdk.resource.model.Platform;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DeviceAssuranceAndroidPlatform
 */
@JsonPropertyOrder({ DeviceAssuranceAndroidPlatform.JSON_PROPERTY_DISK_ENCRYPTION_TYPE,
        DeviceAssuranceAndroidPlatform.JSON_PROPERTY_JAILBREAK, DeviceAssuranceAndroidPlatform.JSON_PROPERTY_OS_VERSION,
        DeviceAssuranceAndroidPlatform.JSON_PROPERTY_SCREEN_LOCK_TYPE,
        DeviceAssuranceAndroidPlatform.JSON_PROPERTY_SECURE_HARDWARE_PRESENT })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
@JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXISTING_PROPERTY, property = "platform", visible = true, defaultImpl = DeviceAssuranceAndroidPlatform.class)

public class DeviceAssuranceAndroidPlatform extends DeviceAssurance implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DISK_ENCRYPTION_TYPE = "diskEncryptionType";
    private DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType diskEncryptionType;

    public static final String JSON_PROPERTY_JAILBREAK = "jailbreak";
    private Boolean jailbreak;

    public static final String JSON_PROPERTY_OS_VERSION = "osVersion";
    private OSVersion osVersion;

    public static final String JSON_PROPERTY_SCREEN_LOCK_TYPE = "screenLockType";
    private DeviceAssuranceAndroidPlatformAllOfScreenLockType screenLockType;

    public static final String JSON_PROPERTY_SECURE_HARDWARE_PRESENT = "secureHardwarePresent";
    private Boolean secureHardwarePresent;

    public DeviceAssuranceAndroidPlatform() {
    }

    /*
     * @JsonCreator public DeviceAssuranceAndroidPlatform(
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_BY) String createdBy,
     *
     * @JsonProperty(JSON_PROPERTY_CREATED_DATE) String createdDate,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATE) String lastUpdate,
     *
     * @JsonProperty(JSON_PROPERTY_LAST_UPDATED_BY) String lastUpdatedBy ) { this(); this.createdBy = createdBy;
     * this.createdDate = createdDate; this.id = id; this.lastUpdate = lastUpdate; this.lastUpdatedBy = lastUpdatedBy; }
     */

    public DeviceAssuranceAndroidPlatform diskEncryptionType(
            DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType diskEncryptionType) {

        this.diskEncryptionType = diskEncryptionType;
        return this;
    }

    /**
     * Get diskEncryptionType
     *
     * @return diskEncryptionType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DISK_ENCRYPTION_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType getDiskEncryptionType() {
        return diskEncryptionType;
    }

    @JsonProperty(JSON_PROPERTY_DISK_ENCRYPTION_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDiskEncryptionType(DeviceAssuranceAndroidPlatformAllOfDiskEncryptionType diskEncryptionType) {
        this.diskEncryptionType = diskEncryptionType;
    }

    public DeviceAssuranceAndroidPlatform jailbreak(Boolean jailbreak) {

        this.jailbreak = jailbreak;
        return this;
    }

    /**
     * Get jailbreak
     *
     * @return jailbreak
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_JAILBREAK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getJailbreak() {
        return jailbreak;
    }

    @JsonProperty(JSON_PROPERTY_JAILBREAK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setJailbreak(Boolean jailbreak) {
        this.jailbreak = jailbreak;
    }

    public DeviceAssuranceAndroidPlatform osVersion(OSVersion osVersion) {

        this.osVersion = osVersion;
        return this;
    }

    /**
     * Get osVersion
     *
     * @return osVersion
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OS_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OSVersion getOsVersion() {
        return osVersion;
    }

    @JsonProperty(JSON_PROPERTY_OS_VERSION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOsVersion(OSVersion osVersion) {
        this.osVersion = osVersion;
    }

    public DeviceAssuranceAndroidPlatform screenLockType(
            DeviceAssuranceAndroidPlatformAllOfScreenLockType screenLockType) {

        this.screenLockType = screenLockType;
        return this;
    }

    /**
     * Get screenLockType
     *
     * @return screenLockType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SCREEN_LOCK_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DeviceAssuranceAndroidPlatformAllOfScreenLockType getScreenLockType() {
        return screenLockType;
    }

    @JsonProperty(JSON_PROPERTY_SCREEN_LOCK_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setScreenLockType(DeviceAssuranceAndroidPlatformAllOfScreenLockType screenLockType) {
        this.screenLockType = screenLockType;
    }

    public DeviceAssuranceAndroidPlatform secureHardwarePresent(Boolean secureHardwarePresent) {

        this.secureHardwarePresent = secureHardwarePresent;
        return this;
    }

    /**
     * Get secureHardwarePresent
     *
     * @return secureHardwarePresent
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SECURE_HARDWARE_PRESENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getSecureHardwarePresent() {
        return secureHardwarePresent;
    }

    @JsonProperty(JSON_PROPERTY_SECURE_HARDWARE_PRESENT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSecureHardwarePresent(Boolean secureHardwarePresent) {
        this.secureHardwarePresent = secureHardwarePresent;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceAndroidPlatform deviceAssuranceAndroidPlatform = (DeviceAssuranceAndroidPlatform) o;
        return Objects.equals(this.diskEncryptionType, deviceAssuranceAndroidPlatform.diskEncryptionType)
                && Objects.equals(this.jailbreak, deviceAssuranceAndroidPlatform.jailbreak)
                && Objects.equals(this.osVersion, deviceAssuranceAndroidPlatform.osVersion)
                && Objects.equals(this.screenLockType, deviceAssuranceAndroidPlatform.screenLockType)
                && Objects.equals(this.secureHardwarePresent, deviceAssuranceAndroidPlatform.secureHardwarePresent);
        // && super.equals(o);
    }

    @Override
    public int hashCode() {
        return Objects.hash(diskEncryptionType, jailbreak, osVersion, screenLockType, secureHardwarePresent,
                super.hashCode());
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceAndroidPlatform {\n");
        sb.append("    ").append(toIndentedString(super.toString())).append("\n");
        sb.append("    diskEncryptionType: ").append(toIndentedString(diskEncryptionType)).append("\n");
        sb.append("    jailbreak: ").append(toIndentedString(jailbreak)).append("\n");
        sb.append("    osVersion: ").append(toIndentedString(osVersion)).append("\n");
        sb.append("    screenLockType: ").append(toIndentedString(screenLockType)).append("\n");
        sb.append("    secureHardwarePresent: ").append(toIndentedString(secureHardwarePresent)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
